==> cvsnt-2.5.02.2115.tar.gz: cvsnt-2.5.02.2115/cvsapi/cvsapi.h <==
/*
	CVSNT Generic API
    Copyright (C) 2004-5 Tony Hoyle and March-Hare Software Ltd

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License version 2.1 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef CVSAPI__H
#define CVSAPI__H

#ifdef _WIN32
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <tchar.h>
#define SECURITY_WIN32
#include <security.h>
#endif

#ifdef _WIN32
#include "win32/config.h"
#else
#include <config.h>
#endif
#include "lib/api_system.h"

#include "cvs_smartptr.h"
#include "cvs_string.h"
#include "GetOptions.h"
#include "RunFile.h"
#include "TokenLine.h"
#include "FileEntry.h"
#include "FileAccess.h"
#include "DirectoryAccess.h"
#include "TagDate.h"
#include "SqlConnection.h"
#include "SqlRecordset.h"
#include "ServerIO.h"
#include "Codepage.h"
#include "diff/DiffBase.h"
#include "diff/StringDiff.h"
#include "SplitPath.h"
#include "SocketIO.h"
#include "md5calc.h"
#include "Xmlapi.h"
#include "rpcBase.h"
#include "SSPIHandler.h"
#include "HttpSocket.h"
#include "Zeroconf.h"
#include "LibraryAccess.h"

#include "lib/getdate.h"

#endif

==> cvsnt_2.5.03.2151.orig.tar.gz: cvsnt-2.5.03.2151/cvsapi/cvsapi.h <==
/*
	CVSNT Generic API
    Copyright (C) 2004-5 Tony Hoyle and March-Hare Software Ltd

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License version 2.1 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef CVSAPI__H
#define CVSAPI__H

#ifdef _WIN32
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <tchar.h>
#define SECURITY_WIN32
#include <security.h>
#endif

#ifdef _WIN32
#include "win32/config.h"
#else
#include <config.h>
#endif
#include "lib/api_system.h"

#include "cvs_smartptr.h"
#include "cvs_string.h"
#include "GetOptions.h"
#include "RunFile.h"
#include "TokenLine.h"
#include "FileEntry.h"
#include "FileAccess.h"
#include "DirectoryAccess.h"
#include "TagDate.h"
#include "SqlConnection.h"
#include "SqlRecordset.h"
#include "ServerIO.h"
#include "Codepage.h"
//#include "diff/DiffBase.h"
//#include "diff/StringDiff.h"
#include "SplitPath.h"
#include "SocketIO.h"
#include "md5calc.h"
#include "Xmlapi.h"
#include "rpcBase.h"
#include "SSPIHandler.h"
#include "HttpSocket.h"
#include "Zeroconf.h"
#include "LibraryAccess.h"
#include "DnsApi.h"

#include "lib/getdate.h"

#endif
